@@ -28,6 +28,7 @@
 
 #include "vinagre-notebook.h"
 #include "vinagre-utils.h"
+#include "vinagre-prefs.h"
 
 #define VINAGRE_NOTEBOOK_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), VINAGRE_TYPE_NOTEBOOK, VinagreNotebookPrivate))
 
@@ -55,13 +56,41 @@ vinagre_notebook_new (VinagreWindow *window)
   return GTK_WIDGET (nb);
 }
 
+void
+vinagre_notebook_show_hide_tabs (VinagreNotebook *nb)
+{
+  gboolean always;
+  gint     n;
+
+  n = gtk_notebook_get_n_pages (GTK_NOTEBOOK (nb));
+
+  g_object_get (vinagre_prefs_get_default (),
+		"always-show-tabs", &always,
+		NULL);
+
+  gtk_notebook_set_show_tabs (GTK_NOTEBOOK (nb),
+			      (n > 1) || (always));
+}
+
 static void
 vinagre_notebook_init (VinagreNotebook *notebook)
 {
   notebook->priv = VINAGRE_NOTEBOOK_GET_PRIVATE (notebook);
 
   gtk_notebook_set_scrollable (GTK_NOTEBOOK (notebook), TRUE);
-  gtk_notebook_set_show_tabs (GTK_NOTEBOOK (notebook), TRUE);
+
+  g_signal_connect (notebook,
+		    "page-added",
+		    G_CALLBACK (vinagre_notebook_show_hide_tabs),
+		    NULL);
+  g_signal_connect (notebook,
+		    "page-removed",
+		    G_CALLBACK (vinagre_notebook_show_hide_tabs),
+		    NULL);
+  g_signal_connect_swapped (vinagre_prefs_get_default (),
+			    "notify::always-show-tabs",
+			     G_CALLBACK (vinagre_notebook_show_hide_tabs),
+			     notebook);
 }
 
 static void
@@ -94,7 +123,7 @@ tab_disconnected_cb (VinagreTab *tab, VinagreNotebook *nb)
 {
   gchar *message, *name;
 
-  name = vinagre_connection_best_name (vinagre_tab_get_conn (tab));
+  name = vinagre_connection_get_best_name (vinagre_tab_get_conn (tab));
   message = g_strdup_printf (_("Connection to host \"%s\" was closed."),
 			     name);
   vinagre_utils_show_error (message, GTK_WINDOW (nb->priv->window));
@@ -138,7 +167,10 @@ build_tab_label (VinagreNotebook *nb,
   rcstyle = gtk_rc_style_new ();
   rcstyle->xthickness = rcstyle->ythickness = 0;
   gtk_widget_modify_style (close_button, rcstyle);
-  gtk_rc_style_unref (rcstyle),
+  gtk_rc_style_unref (rcstyle);
+  gint w, h;
+  gtk_icon_size_lookup (GTK_ICON_SIZE_MENU, &w, &h);
+  gtk_widget_set_size_request (GTK_WIDGET (close_button), w+2, h+2);
 
   image = gtk_image_new_from_stock (GTK_STOCK_CLOSE,
 					  GTK_ICON_SIZE_MENU);
@@ -157,7 +189,7 @@ build_tab_label (VinagreNotebook *nb,
   gtk_box_pack_start (GTK_BOX (label_hbox), icon, FALSE, FALSE, 0);
 	
   /* setup label */
-  name = vinagre_connection_best_name (vinagre_tab_get_conn (tab));
+  name = vinagre_connection_get_best_name (vinagre_tab_get_conn (tab));
   label = gtk_label_new (name);
   g_free (name);
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
