@@ -2,7 +2,7 @@
  * vinagre-ui.h
  * This file is part of vinagre
  *
- * Copyright (C) 2007 - Jonh Wendell <wendell@bani.com.br>
+ * Copyright (C) 2007,2008 - Jonh Wendell <wendell@bani.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,9 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, 
- * Boston, MA 02111-1307, USA.
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef __VINAGRE_UI_H__
@@ -35,30 +33,28 @@ static const GtkActionEntry vinagre_always_sensitive_menu_entries[] =
   { "Machine", NULL, N_("_Machine") },
   { "Edit", NULL, N_("_Edit") },
   { "View", NULL, N_("_View") },
-  { "Favorites", NULL, N_("_Favorites") },
+  { "Bookmarks", NULL, N_("_Bookmarks") },
   { "Help", NULL, N_("_Help") },
 
   /* Machine menu */
   { "MachineConnect", GTK_STOCK_CONNECT, NULL, "<control>N",
     N_("Connect into a remote machine"), G_CALLBACK (vinagre_cmd_machine_connect) },
+  { "MachineOpen", GTK_STOCK_OPEN, NULL, "<control>O",
+    N_("Open a .VNC file"), G_CALLBACK (vinagre_cmd_machine_open) },
   { "MachineQuit", GTK_STOCK_QUIT, NULL, "<control>Q",
-    N_("Quit the program"), G_CALLBACK (gtk_main_quit) },
+    N_("Quit the program"), G_CALLBACK (vinagre_cmd_machine_quit) },
   	
-  /* Edit menu */
-  { "EditPreferences", GTK_STOCK_PREFERENCES, N_("_Preferences"), NULL,
-    N_("Configure the application"), NULL },
-
-  /* Favorites menu */
-  { "FavoritesOpen", GTK_STOCK_CONNECT, N_("_Open favorite"), NULL,
-    N_("Connect to this favorite"), G_CALLBACK (vinagre_cmd_favorites_open) },
-  { "FavoritesEdit", GTK_STOCK_EDIT, N_("_Edit favorite"), NULL,
-    N_("Edit the details of selected favorite"), G_CALLBACK (vinagre_cmd_favorites_edit) },
-  { "FavoritesDel", GTK_STOCK_DELETE, N_("_Remove from favorites"), NULL,
-    N_("Remove current selected connection from favorites"), G_CALLBACK (vinagre_cmd_favorites_del) },
+  /* Bookmarks menu */
+  { "BookmarksOpen", GTK_STOCK_CONNECT, N_("_Open bookmark"), NULL,
+    N_("Connect into this machine"), G_CALLBACK (vinagre_cmd_bookmarks_open) },
+  { "BookmarksEdit", GTK_STOCK_EDIT, N_("_Edit bookmark"), NULL,
+    N_("Edit the details of selected bookmark"), G_CALLBACK (vinagre_cmd_bookmarks_edit) },
+  { "BookmarksDel", GTK_STOCK_DELETE, N_("_Remove from bookmarks"), NULL,
+    N_("Remove current selected connection from bookmarks"), G_CALLBACK (vinagre_cmd_bookmarks_del) },
 
   /* Help menu */
   {"HelpContents", GTK_STOCK_HELP, N_("_Contents"), "F1",
-    N_("Open the vinagre manual"), NULL },
+    N_("Open the vinagre manual"),  G_CALLBACK (vinagre_cmd_help_contents)},
   { "HelpAbout", GTK_STOCK_ABOUT, NULL, NULL,
     N_("About this application"), G_CALLBACK (vinagre_cmd_help_about) }
 };
@@ -68,25 +64,37 @@ static const GtkActionEntry vinagre_menu_entries[] =
   /* Machine menu */
   { "MachineClose", GTK_STOCK_CLOSE, NULL, "<control>W",
     N_("Close the current connection"), G_CALLBACK (vinagre_cmd_machine_close) },
-  { "MachineTakeScreenshot", "applets-screenshooter", N_("Take screenshot"), NULL,
-    N_("Take a screenshot of active connection"), G_CALLBACK (vinagre_cmd_machine_take_screenshot) },
   { "MachineCloseAll", GTK_STOCK_CLOSE, N_("C_lose All"), "<control><shift>W",
     N_("Close all active connections"), G_CALLBACK (vinagre_cmd_machine_close_all) },
 
-  /* Edit menu */
-  { "EditCopy", GTK_STOCK_COPY, NULL, "<control>C",
-    N_("Copy the selection"), NULL },
-  { "EditPaste", GTK_STOCK_PASTE, NULL, "<control>V",
-    N_("Paste the clipboard"), NULL },
+  /* Bookmarks menu */
+  { "BookmarksAdd", GTK_STOCK_SAVE, N_("_Add to bookmarks"), "<control>D",
+    N_("Add current connection to your bookmarks"), G_CALLBACK (vinagre_cmd_bookmarks_add) }
+
+};
+
+static const GtkActionEntry vinagre_machine_connected_menu_entries[] =
+{
+  /* Machine menu */
+  { "MachineTakeScreenshot", "applets-screenshooter", N_("Take screenshot"), NULL,
+    N_("Take a screenshot of active connection"), G_CALLBACK (vinagre_cmd_machine_take_screenshot) },
+
+  { "MachineSendCtrlAltDel", "preferences-desktop-keyboard-shortcuts", N_("Send Ctrl-Alt-Del"), NULL,
+    N_("Send Ctrl+Alt+Del to active connection"), G_CALLBACK (vinagre_cmd_machine_send_ctrlaltdel) },
 
   /* View menu */
   { "ViewFullScreen", GTK_STOCK_FULLSCREEN, NULL, "F11",
     N_("View the current machine in full screen"), G_CALLBACK (vinagre_cmd_view_fullscreen) },
+};
 
-  /* Favorites menu */
-  { "FavoritesAdd", GTK_STOCK_SAVE, N_("_Add to favorites"), "<control>D",
-    N_("Add current connection to favorites"), G_CALLBACK (vinagre_cmd_favorites_add) }
-
+static const GtkToggleActionEntry vinagre_machine_connected_toggle_menu_entries[] =
+{
+  { "ViewScaling", NULL, N_("S_caling"), NULL,
+    N_("Fit the remote screen into the current window size"),
+    G_CALLBACK (vinagre_cmd_view_scaling), FALSE },
+  { "ViewReadOnly", NULL, N_("_Read only"), NULL,
+    N_("Disable mouse and keyboard activities"),
+    G_CALLBACK (vinagre_cmd_view_readonly), FALSE }
 };
 
 static const GtkToggleActionEntry vinagre_always_sensitive_toggle_menu_entries[] =
@@ -99,11 +107,12 @@ static const GtkToggleActionEntry vinagre_always_sensitive_toggle_menu_entries[]
     N_("Show or hide the statusbar"),
     G_CALLBACK (vinagre_cmd_view_show_statusbar), FALSE },
 
-  { "ViewFavorites", NULL, N_("_Favorites"), "F9",
-    N_("Show or hide the favorites panel"),
+  { "ViewSidePanel", NULL, N_("Side _Panel"), "F9",
+    N_("Show or hide the side panel"),
     G_CALLBACK (vinagre_cmd_view_show_fav_panel), FALSE }
 };
 
 G_END_DECLS
 
 #endif  /* __VINAGRE_UI_H__  */
+/* vim: ts=8 */
