@@ -192,25 +192,6 @@ vinagre_window_configure_event (GtkWidget         *widget,
   return GTK_WIDGET_CLASS (vinagre_window_parent_class)->configure_event (widget, event);
 }
 
-
-static gboolean
-vinagre_window_key_press_cb (GtkWidget   *widget,
-			     GdkEventKey *event)
-{
-  VinagreWindow *window = VINAGRE_WINDOW (widget);
-
-  switch (event->keyval)
-    {
-      case GDK_F11:
-	if (window->priv->active_tab &&
-	    (vinagre_tab_get_state (VINAGRE_TAB (window->priv->active_tab)) == VINAGRE_TAB_STATE_CONNECTED))
-	  vinagre_window_toggle_fullscreen (window);
-	return FALSE;
-    }
-
-  return GTK_WIDGET_CLASS (vinagre_window_parent_class)->key_press_event (widget, event);
-}
-
 static void
 vinagre_window_class_init (VinagreWindowClass *klass)
 {
@@ -220,7 +201,6 @@ vinagre_window_class_init (VinagreWindowClass *klass)
   object_class->finalize = vinagre_window_finalize;
   object_class->dispose  = vinagre_window_dispose;
 
-  widget_class->key_press_event    = vinagre_window_key_press_cb;
   widget_class->window_state_event = vinagre_window_state_event_cb;
   widget_class->configure_event    = vinagre_window_configure_event;
   widget_class->delete_event       = vinagre_window_delete_event;
@@ -339,6 +319,19 @@ recent_manager_changed (GtkRecentManager *manager,
   update_recent_connections (window);
 }
 
+static void
+show_hide_accels (VinagreWindow *window)
+{
+  gboolean show_accels;
+
+  g_object_get (vinagre_prefs_get_default (),
+		"show-accels", &show_accels,
+		NULL);
+  g_object_set (gtk_settings_get_default (),
+		"gtk-enable-accels", show_accels,
+		NULL);
+}
+
 static void
 create_menu_bar_and_toolbar (VinagreWindow *window, 
 			     GtkWidget     *main_box)
@@ -491,6 +484,12 @@ create_menu_bar_and_toolbar (VinagreWindow *window,
 		    "changed",
 		    G_CALLBACK (recent_manager_changed),
 		    window);
+
+  g_signal_connect_swapped (vinagre_prefs_get_default (),
+			    "notify::show-accels",
+			     G_CALLBACK (show_hide_accels),
+			     window);
+  show_hide_accels (window);
 }
 
 void
@@ -525,9 +524,6 @@ fav_panel_activated (VinagreFav        *fav,
 		     VinagreConnection *conn,
 		     VinagreWindow     *window)
 {
-  g_return_if_fail (VINAGRE_IS_FAV (fav));
-  g_return_if_fail (VINAGRE_IS_WINDOW (window));
-
   vinagre_cmd_open_bookmark (window, conn);
 }
 
@@ -801,7 +797,7 @@ create_statusbar (VinagreWindow *window,
 void
 vinagre_window_set_title (VinagreWindow *window)
 {
-  gchar *title, *name;
+  gchar *title, *name, *grab;
 
   if (window->priv->active_tab == NULL)
     {
@@ -809,13 +805,20 @@ vinagre_window_set_title (VinagreWindow *window)
       return;
     }
 
+  if (vinagre_tab_is_pointer_grab (VINAGRE_TAB (window->priv->active_tab)))
+    grab = g_strdup_printf (" (%s)", _("Press Ctrl+Alt to release the cursor"));
+  else
+    grab = g_strdup ("");
+
   name = vinagre_connection_get_best_name (vinagre_tab_get_conn (VINAGRE_TAB (window->priv->active_tab)));
-  title = g_strdup_printf ("%s - %s",
+  title = g_strdup_printf ("%s%s - %s",
 			   name,
+			   grab,
 			   g_get_application_name ());
   gtk_window_set_title (GTK_WINDOW (window), title);
   g_free (title);
   g_free (name);
+  g_free (grab);
 }
 
 static void
@@ -1131,6 +1134,14 @@ vinagre_window_get_sensitive_action (VinagreWindow *window)
   return window->priv->always_sensitive_action_group;
 }
 
+GtkActionGroup *
+vinagre_window_get_connected_action (VinagreWindow *window)
+{
+  g_return_val_if_fail (VINAGRE_IS_WINDOW (window), NULL);
+
+  return window->priv->machine_connected_action_group;
+}
+
 GtkWidget *
 vinagre_window_get_fav_panel (VinagreWindow *window)
 {
